@@ -1,6 +1,6 @@
 
 import unittest
-from math import exp, sqrt
+from math import exp
 from datetime import datetime, timedelta
 
 import numpy as np
